==> ibiz-model-util-8.1.0.372-sources.jar: net/ibizsys/model/util/transpiler/extend/control/form/PSDEFDLogicListTranspilerEx.java <==
package net.ibizsys.model.util.transpiler.extend.control.form;

import net.ibizsys.model.IPSModelObject;
import net.ibizsys.model.control.form.IPSDEFDGroupLogic;
import net.ibizsys.model.control.form.IPSDEFDLogic;
import net.ibizsys.model.util.transpiler.IPSModelTranspileContext;
import net.ibizsys.psmodel.core.domain.PSDEFDLogic;
import net.ibizsys.psmodel.core.util.IPSModel;

public class PSDEFDLogicListTranspilerEx extends net.ibizsys.model.util.transpiler.control.form.PSDEFDLogicListTranspiler{
	@Override
	protected void onDecompile(IPSModelTranspileContext iPSModelTranspileContext, IPSModelObject iPSModelObject, IPSModel domain, boolean bFullMode) throws Exception {
		super.onDecompile(iPSModelTranspileContext, iPSModelObject, domain, bFullMode);
		
		if(bFullMode) {
			IPSDEFDLogic iPSDEFDLogic = (IPSDEFDLogic)iPSModelObject;
			PSDEFDLogic psDEFDLogic = (PSDEFDLogic)domain;
			if(iPSDEFDLogic instanceof IPSDEFDGroupLogic) {
				IPSDEFDGroupLogic iPSDEFDGroupLogic = (IPSDEFDGroupLogic)iPSDEFDLogic;
				if(iPSDEFDGroupLogic.getPSDEFDLogics()!=null) {
					int nOrder = 100;
					iPSModelTranspileContext.getPSModelListTranspiler(IPSDEFDLogic.class, false).decompile(iPSModelTranspileContext, iPSDEFDGroupLogic.getPSDEFDLogics(), psDEFDLogic.getPSDEFDLogicsIf(), bFullMode);
					for(PSDEFDLogic child : psDEFDLogic.getPSDEFDLogicsIf()) {
						child.setPPSDEFDLogicId(psDEFDLogic.getId());
						child.setPPSDEFDLogicName(psDEFDLogic.getName());
						child.setOrderValue(nOrder);
						nOrder += 100;
					}
				}
			}
		}
	}
}

==> ibiz-model-util-8.1.0.458-sources.jar: net/ibizsys/model/util/transpiler/extend/control/form/PSDEFDLogicListTranspilerEx.java <==
package net.ibizsys.model.util.transpiler.extend.control.form;

import org.springframework.util.ObjectUtils;

import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import net.ibizsys.model.IPSModelObject;
import net.ibizsys.model.control.form.IPSDEFDGroupLogic;
import net.ibizsys.model.control.form.IPSDEFDLogic;
import net.ibizsys.model.control.form.PSDEFDGroupLogicImpl;
import net.ibizsys.model.util.transpiler.IPSModelTranspileContext;
import net.ibizsys.psmodel.core.domain.PSDEFDLogic;
import net.ibizsys.psmodel.core.util.IPSModel;

public class PSDEFDLogicListTranspilerEx extends net.ibizsys.model.util.transpiler.control.form.PSDEFDLogicListTranspiler{
	@Override
	protected void onDecompile(IPSModelTranspileContext iPSModelTranspileContext, IPSModelObject iPSModelObject, IPSModel domain, boolean bFullMode) throws Exception {
		super.onDecompile(iPSModelTranspileContext, iPSModelObject, domain, bFullMode);
		
		if(bFullMode) {
			IPSDEFDLogic iPSDEFDLogic = (IPSDEFDLogic)iPSModelObject;
			PSDEFDLogic psDEFDLogic = (PSDEFDLogic)domain;
			if(iPSDEFDLogic instanceof IPSDEFDGroupLogic) {
				IPSDEFDGroupLogic iPSDEFDGroupLogic = (IPSDEFDGroupLogic)iPSDEFDLogic;
				if(iPSDEFDGroupLogic.getPSDEFDLogics()!=null) {
					int nOrder = 100;
					iPSModelTranspileContext.getPSModelListTranspiler(IPSDEFDLogic.class, false).decompile(iPSModelTranspileContext, iPSDEFDGroupLogic.getPSDEFDLogics(), psDEFDLogic.getPSDEFDLogicsIf(), bFullMode);
					for(PSDEFDLogic child : psDEFDLogic.getPSDEFDLogicsIf()) {
						child.setPPSDEFDLogicId(psDEFDLogic.getId());
						child.setPPSDEFDLogicName(psDEFDLogic.getName());
						child.setOrderValue(nOrder);
						nOrder += 100;
					}
				}
			}
		}
	}
	
	@Override
	protected void onCompile(IPSModelTranspileContext iPSModelTranspileContext, IPSModel domain, ObjectNode objectNode) throws Exception {
		super.onCompile(iPSModelTranspileContext, domain, objectNode);
		
		PSDEFDLogic psDEFDLogic = (PSDEFDLogic)domain;
		if(!ObjectUtils.isEmpty(psDEFDLogic.getPSDEFDLogics())) {
			ArrayNode arrayNode = objectNode.putArray(PSDEFDGroupLogicImpl.ATTR_GETPSDEFDLOGICS);
			iPSModelTranspileContext.getPSModelListTranspiler(IPSDEFDLogic.class, false).compile(iPSModelTranspileContext, psDEFDLogic.getPSDEFDLogics(), arrayNode);
		}
	}
}
